@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 import pytest
 from pytest_lazy_fixtures.lazy_fixture import lf as lazy_fixture
@@ -11,7 +11,10 @@ from tests.const import (
     MAIN_PROG_NAME,
     VERSION_SUBCMD,
 )
-from tests.fixtures.commit_parsers import conventional_minor_commits
+from tests.fixtures.commit_parsers import (
+    conventional_minor_commits,
+    default_conventional_parser,
+)
 from tests.fixtures.git_repo import get_commit_def_of_conventional_commit
 from tests.fixtures.repos import (
     repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits_using_tag_format,
@@ -34,7 +37,11 @@ if TYPE_CHECKING:
 
     from requests_mock import Mocker
 
+    from semantic_release.commit_parser._base import CommitParser, ParserOptions
+    from semantic_release.commit_parser.token import ParseResult
+
     from tests.conftest import RunCliFn
+    from tests.e2e.conftest import StripLoggingMessagesFn
     from tests.fixtures.git_repo import (
         BuiltRepoResult,
         GetCfgValueFromDefFn,
@@ -98,6 +105,7 @@ def test_version_print_next_version(
     next_release_version: str,
     file_in_repo: str,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -135,7 +143,7 @@ def test_version_print_next_version(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -262,6 +270,7 @@ def test_version_print_tag_prints_next_tag(
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     file_in_repo: str,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -303,7 +312,7 @@ def test_version_print_tag_prints_next_tag(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -377,6 +386,7 @@ def test_version_print_tag_prints_next_tag_no_zero_versions(
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     file_in_repo: str,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -418,7 +428,7 @@ def test_version_print_tag_prints_next_tag_no_zero_versions(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -440,8 +450,10 @@ def test_version_print_last_released_prints_version(
     repo_result: BuiltRepoResult,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     latest_release_version = get_versions_from_repo_build_def(
@@ -461,11 +473,11 @@ def test_version_print_last_released_prints_version(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
+    assert not strip_logging_messages(result.stderr)
     assert f"{latest_release_version}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -490,9 +502,11 @@ def test_version_print_last_released_prints_released_if_commits(
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     commits: list[str],
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
     file_in_repo: str,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     latest_release_version = get_versions_from_repo_build_def(
@@ -516,11 +530,11 @@ def test_version_print_last_released_prints_released_if_commits(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
+    assert not strip_logging_messages(result.stderr)
     assert f"{latest_release_version}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -538,6 +552,7 @@ def test_version_print_last_released_prints_released_if_commits(
 def test_version_print_last_released_prints_nothing_if_no_tags(
     repo_result: BuiltRepoResult,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
     caplog: pytest.LogCaptureFixture,
@@ -557,7 +572,7 @@ def test_version_print_last_released_prints_nothing_if_no_tags(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate (no release actions should have occurred on print)
     assert_successful_exit_code(result, cli_cmd)
@@ -583,8 +598,10 @@ def test_version_print_last_released_on_detached_head(
     repo_result: BuiltRepoResult,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     latest_release_version = get_versions_from_repo_build_def(
@@ -607,11 +624,11 @@ def test_version_print_last_released_on_detached_head(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate (expected -> actual)
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
+    assert not strip_logging_messages(result.stderr)
     assert f"{latest_release_version}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -630,8 +647,10 @@ def test_version_print_last_released_on_nonrelease_branch(
     repo_result: BuiltRepoResult,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     latest_release_version = get_versions_from_repo_build_def(
@@ -654,11 +673,11 @@ def test_version_print_last_released_on_nonrelease_branch(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate (expected -> actual)
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
+    assert not strip_logging_messages(result.stderr)
     assert f"{latest_release_version}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -686,8 +705,10 @@ def test_version_print_last_released_tag_prints_correct_tag(
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     repo_def = repo_result["definition"]
@@ -708,11 +729,11 @@ def test_version_print_last_released_tag_prints_correct_tag(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
+    assert not strip_logging_messages(result.stderr)
     assert f"{latest_release_tag}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -745,9 +766,11 @@ def test_version_print_last_released_tag_prints_released_if_commits(
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     commits: list[str],
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
     file_in_repo: str,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     repo_def = repo_result["definition"]
@@ -772,11 +795,11 @@ def test_version_print_last_released_tag_prints_released_if_commits(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
+    assert not strip_logging_messages(result.stderr)
     assert f"{latest_release_tag}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -794,6 +817,7 @@ def test_version_print_last_released_tag_prints_released_if_commits(
 def test_version_print_last_released_tag_prints_nothing_if_no_tags(
     repo_result: BuiltRepoResult,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
     caplog: pytest.LogCaptureFixture,
@@ -813,7 +837,7 @@ def test_version_print_last_released_tag_prints_nothing_if_no_tags(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate (no release actions should have occurred on print)
     assert_successful_exit_code(result, cli_cmd)
@@ -848,8 +872,10 @@ def test_version_print_last_released_tag_on_detached_head(
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     repo_def = repo_result["definition"]
@@ -873,11 +899,11 @@ def test_version_print_last_released_tag_on_detached_head(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate (expected -> actual)
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
+    assert not strip_logging_messages(result.stderr)
     assert f"{latest_release_tag}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -905,8 +931,10 @@ def test_version_print_last_released_tag_on_nonrelease_branch(
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     run_cli: RunCliFn,
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     repo_def = repo_result["definition"]
@@ -930,11 +958,11 @@ def test_version_print_last_released_tag_on_nonrelease_branch(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate (expected -> actual)
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
+    assert not strip_logging_messages(result.stderr)
     assert f"{last_release_tag}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -946,11 +974,12 @@ def test_version_print_last_released_tag_on_nonrelease_branch(
 
 
 @pytest.mark.parametrize(
-    "repo_result, get_commit_def_fn",
+    "repo_result, get_commit_def_fn, default_parser",
     [
         (
             lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
             lazy_fixture(get_commit_def_of_conventional_commit.__name__),
+            lazy_fixture(default_conventional_parser.__name__),
         )
     ],
 )
@@ -958,9 +987,12 @@ def test_version_print_next_version_fails_on_detached_head(
     repo_result: BuiltRepoResult,
     run_cli: RunCliFn,
     simulate_change_commits_n_rtn_changelog_entry: SimulateChangeCommitsNReturnChangelogEntryFn,
-    get_commit_def_fn: GetCommitDefFn,
+    get_commit_def_fn: GetCommitDefFn[CommitParser[ParseResult, ParserOptions]],
+    default_parser: CommitParser[ParseResult, ParserOptions],
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     expected_error_msg = (
@@ -973,7 +1005,7 @@ def test_version_print_next_version_fails_on_detached_head(
     # Setup: make a commit to ensure we have something to release
     simulate_change_commits_n_rtn_changelog_entry(
         repo,
-        [get_commit_def_fn("fix: make a patch fix to codebase")],
+        [get_commit_def_fn("fix: make a patch fix to codebase", parser=default_parser)],
     )
 
     # Setup: take measurement before running the version command
@@ -989,12 +1021,12 @@ def test_version_print_next_version_fails_on_detached_head(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate (expected -> actual)
     assert_exit_code(1, result, cli_cmd)
     assert not result.stdout
-    assert f"{expected_error_msg}\n" == result.stderr
+    assert f"{expected_error_msg}\n" == strip_logging_messages(result.stderr)
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
     assert repo_status_before == repo_status_after
@@ -1005,11 +1037,12 @@ def test_version_print_next_version_fails_on_detached_head(
 
 
 @pytest.mark.parametrize(
-    "repo_result, get_commit_def_fn",
+    "repo_result, get_commit_def_fn, default_parser",
     [
         (
             lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
             lazy_fixture(get_commit_def_of_conventional_commit.__name__),
+            lazy_fixture(default_conventional_parser.__name__),
         )
     ],
 )
@@ -1017,9 +1050,12 @@ def test_version_print_next_tag_fails_on_detached_head(
     repo_result: BuiltRepoResult,
     run_cli: RunCliFn,
     simulate_change_commits_n_rtn_changelog_entry: SimulateChangeCommitsNReturnChangelogEntryFn,
-    get_commit_def_fn: GetCommitDefFn,
+    get_commit_def_fn: GetCommitDefFn[CommitParser[ParseResult, ParserOptions]],
+    default_parser: CommitParser[ParseResult, ParserOptions],
+    mocked_git_fetch: MagicMock,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
+    strip_logging_messages: StripLoggingMessagesFn,
 ):
     repo = repo_result["repo"]
     expected_error_msg = (
@@ -1032,7 +1068,7 @@ def test_version_print_next_tag_fails_on_detached_head(
     # Setup: make a commit to ensure we have something to release
     simulate_change_commits_n_rtn_changelog_entry(
         repo,
-        [get_commit_def_fn("fix: make a patch fix to codebase")],
+        [get_commit_def_fn("fix: make a patch fix to codebase", parser=default_parser)],
     )
 
     # Setup: take measurement before running the version command
@@ -1048,12 +1084,12 @@ def test_version_print_next_tag_fails_on_detached_head(
     repo_status_after = repo.git.status(short=True)
     head_after = repo.head.commit.hexsha
     tags_after = {tag.name for tag in repo.tags}
-    tags_set_difference = set.difference(tags_after, tags_before)
+    tags_set_difference = cast("set[str]", set.difference(tags_after, tags_before))
 
     # Evaluate (expected -> actual)
     assert_exit_code(1, result, cli_cmd)
     assert not result.stdout
-    assert f"{expected_error_msg}\n" == result.stderr
+    assert f"{expected_error_msg}\n" == strip_logging_messages(result.stderr)
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
     assert repo_status_before == repo_status_after
